@@ -6,7 +6,7 @@ PacketFu.packet_classes.each do |pclass|
 		it "will display sensible peek information" do
 			p = pclass.new
 			p.respond_to?(:peek).should be_true
-			p.peek.size.should be_<=(80), p.peek.inspect
+			p.peek.size.should be <= 80, p.peek.inspect
 			p.peek.should match(/^[A-Z0-9?]../)
 		end
 	end
